@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -66,6 +66,20 @@ import java.util.ListResourceBundle;
 public class FormatData_es_419 extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_generic_AmPmMarkers = new String[] {
+            "a.m.",
+            "p.m.",
+            "",
+            "del mediod\u00eda",
+            "de la madrugada",
+            "de la ma\u00f1ana",
+            "",
+            "",
+            "de la tarde",
+            "",
+            "de la noche",
+            "",
+        };
         final String metaValue_generic_DateFormatItem_yyyyMMMd = "d 'de' MMM 'de' y G";
         final String metaValue_generic_DateFormatItem_yyyyMMM = "MMM 'de' y G";
         final String[] metaValue_generic_DayNarrows = new String[] {
@@ -83,15 +97,21 @@ public class FormatData_es_419 extends ListResourceBundle {
             "3.\u00ba trimestre",
             "4.\u00ba trimestre",
         };
-        final String[] metaValue_long_Eras = new String[] {
+        final String[] metaValue_java_time_long_Eras = new String[] {
             "a.C.",
             "d.C.",
         };
         final String[] metaValue_generic_TimePatterns = new String[] {
-            "HH:mm:ss zzzz",
-            "HH:mm:ss z",
-            "HH:mm:ss",
-            "HH:mm",
+            "h:mm:ss\u202fa zzzz",
+            "h:mm:ss\u202fa z",
+            "h:mm:ss\u202fa",
+            "h:mm\u202fa",
+        };
+        final String[] metaValue_generic_DateTimePatterns = new String[] {
+            "{1}, {0}",
+            "{1}, {0}",
+            "{1}, {0}",
+            "{1}, {0}",
         };
         final String metaValue_generic_DateFormatItem_yMMMEd = "E, d MMM y";
         final String metaValue_generic_DateFormatItem_yMEd = "E d/M/y";
@@ -121,20 +141,33 @@ public class FormatData_es_419 extends ListResourceBundle {
             "antes de R.O.C.",
             "R.O.C.",
         };
+        final String[] metaValue_short_CompactNumberPatterns = new String[] {
+            "",
+            "",
+            "",
+            "{one:0\u00a0K other:0\u00a0K}",
+            "{one:00\u00a0k other:00\u00a0k}",
+            "{one:000\u00a0k other:000\u00a0k}",
+            "{one:0\u00a0M other:0\u00a0M}",
+            "{one:00\u00a0M other:00\u00a0M}",
+            "{one:000\u00a0M other:000\u00a0M}",
+            "{one:0000\u00a0M other:0000\u00a0M}",
+            "{one:00\u00a0mil\u00a0M other:00\u00a0mil\u00a0M}",
+            "{one:000\u00a0mil\u00a0M other:000\u00a0mil\u00a0M}",
+            "{one:0\u00a0B other:0\u00a0B}",
+            "{one:00\u00a0B other:00\u00a0B}",
+            "{one:000\u00a0B other:000\u00a0B}",
+        };
         final Object[][] data = new Object[][] {
             { "generic.DayNarrows", metaValue_generic_DayNarrows },
             { "generic.QuarterNames", metaValue_generic_QuarterNames },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "generic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "generic.DateTimePatterns",
-                new String[] {
-                    "{1}, {0}",
-                    "{1}, {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
+            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
             { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "generic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
@@ -159,9 +192,15 @@ public class FormatData_es_419 extends ListResourceBundle {
             { "QuarterNames", metaValue_generic_QuarterNames },
             { "standalone.QuarterNames", metaValue_generic_QuarterNames },
             { "QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "long.Eras", metaValue_long_Eras },
-            { "Eras", metaValue_long_Eras },
-            { "narrow.Eras", metaValue_long_Eras },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "java.time.long.Eras", metaValue_java_time_long_Eras },
+            { "long.Eras", metaValue_java_time_long_Eras },
+            { "java.time.Eras", metaValue_java_time_long_Eras },
+            { "Eras", metaValue_java_time_long_Eras },
+            { "java.time.narrow.Eras", metaValue_java_time_long_Eras },
+            { "narrow.Eras", metaValue_java_time_long_Eras },
             { "field.dayperiod", "a.m./p.m." },
             { "timezone.regionFormat.daylight", "hora de verano de {0}" },
             { "timezone.regionFormat.standard", "hora est\u00e1ndar de {0}" },
@@ -174,14 +213,7 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "d/M/yy",
                 }
             },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1}, {0}",
-                    "{1}, {0}",
-                    "{1} {0}",
-                    "{1}, {0}",
-                }
-            },
+            { "DateTimePatterns", metaValue_generic_DateTimePatterns },
             { "DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
@@ -195,8 +227,10 @@ public class FormatData_es_419 extends ListResourceBundle {
             { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
             { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
             { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
+            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
@@ -213,11 +247,19 @@ public class FormatData_es_419 extends ListResourceBundle {
             { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "buddhist.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
             { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
             { "japanese.QuarterNames", metaValue_generic_QuarterNames },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE, d 'de' MMMM 'de' yyyy GGGG",
+                    "d 'de' MMMM 'de' yyyy GGGG",
+                    "d 'de' MMM 'de' y GGGG",
+                    "d/M/y G",
+                }
+            },
             { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "japanese.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
@@ -233,6 +275,8 @@ public class FormatData_es_419 extends ListResourceBundle {
             { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "roc.DayNarrows", metaValue_generic_DayNarrows },
             { "roc.QuarterNames", metaValue_generic_QuarterNames },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -289,8 +333,9 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "islamic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "islamic.DatePatterns", metaValue_generic_DatePatterns },
@@ -354,48 +399,12 @@ public class FormatData_es_419 extends ListResourceBundle {
                 new String[] {
                     "#,##0.###",
                     "\u00a4#,##0.00",
-                    "#,##0\u00a0%",
-                    "\u00a4#,##0.00",
-                }
-            },
-            { "short.CompactNumberPatterns",
-                new String[] {
+                    "#,##0%",
                     "",
-                    "",
-                    "",
-                    "{one:0\u00a0K other:0\u00a0K}",
-                    "{one:00\u00a0k other:00\u00a0k}",
-                    "{one:000\u00a0k other:000\u00a0k}",
-                    "{one:0\u00a0M other:0\u00a0M}",
-                    "{one:00\u00a0M other:00\u00a0M}",
-                    "{one:000\u00a0M other:000\u00a0M}",
-                    "{one:0000\u00a0M other:0000\u00a0M}",
-                    "{one:00\u00a0mil\u00a0M other:00\u00a0mil\u00a0M}",
-                    "{one:000\u00a0mil\u00a0M other:000\u00a0mil\u00a0M}",
-                    "{one:0\u00a0B other:0\u00a0B}",
-                    "{one:00\u00a0B other:00\u00a0B}",
-                    "{one:000\u00a0B other:000\u00a0B}",
-                }
-            },
-            { "long.CompactNumberPatterns",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "{one:0' 'mil other:0' 'mil}",
-                    "{one:00' 'mil other:00' 'mil}",
-                    "{one:000' 'mil other:000' 'mil}",
-                    "{one:0' 'mill\u00f3n other:0' 'millones}",
-                    "{one:00' 'millones other:00' 'millones}",
-                    "{one:000' 'millones other:000' 'millones}",
-                    "{one:0' 'mil' 'millones other:0' 'mil' 'millones}",
-                    "{one:00' 'mil' 'millones other:00' 'mil' 'millones}",
-                    "{one:000' 'mil' 'millones other:000' 'mil' 'millones}",
-                    "{other:0' 'bill\u00f3n}",
-                    "{other:00' 'billones}",
-                    "{other:000' 'billones}",
                 }
             },
+            { "short.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
+            { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
         };
         return data;
     }
